searchData={"items":[{"type":"module","title":"Minipeg","doc":"# Minipeg is a minimal _Parse Expression Grammars_ (PEG) Library\n\nHere is a first taste of how to use it:\n\n    iex(1)> an_a_parser = char_parser(\"a\")\n    ...(1)> parse_string(an_a_parser, \"a\")\n    {:ok, \"a\"}\n\n    iex(2)> an_a_parser = char_parser(\"a\")\n    ...(2)> parse_string(an_a_parser, \"b\")\n    {:error, \"b not member of \\\"a\\\" in char_parser(\\\"a\\\")  :1,1\"}\n\nThe first thing to note here is that in these doctests we have imported functions from\nMinipeg as follows, see the moduledocs of the corresponding modules for details\n\n  ```elixir\n    import Minipeg.Parser, only: [parse_string: 2]\n    import Minipeg.{Combinators, Parsers}\n  ```","ref":"Minipeg.html"},{"type":"module","title":"Basic Usage - Minipeg","doc":"Quite a small subset of predefined [parsers](#module-definitions) and [combinators](#module-definitions)\nwould suffice to parse any [context free language](https://en.wikipedia.org/wiki/Context-free_language), however many of the patterns used to parse\nprogramming languages, little languages or small languages that exceed the practicallity of [regular expressions](https://en.wikipedia.org/wiki/Regular_expression)\nare quite verbose.\n\nTherefore Minipeg predefines parsers that can be easily parametrized. These parsers will be described in the [utility parsers](#moduledoc-utility-parsers) section.\n\n\n#","ref":"Minipeg.html#module-basic-usage"},{"type":"module","title":"Parsing Single Characters - Minipeg","doc":"With a _character_ we do indeed mean a UTF-8 Code Point\n\nThe most basic parser is the...\n\n#### `char_parser`\n\n... which parses _any_ character\n\n    iex(3)> parse_string(char_parser(), \"h\")\n    {:ok, \"h\"}\n\n\n    iex(4)> parse_string(char_parser(), \"é\")\n    {:ok, \"é\"}\n\n\n    iex(5)> parse_string(char_parser(), \"✓\")\n    {:ok, \"✓\"}\n\n    iex(6)> parse_string(char_parser(), \"\")\n    {:error, \"encountered end of input in char_parser()  :1,1\"}\n\nIt can however be parametrized to parse only characters of a given set, this set can be provided as\na `String` or an `Enumerable`\n\n\n    iex(7)> parse_string(char_parser(\"ab\"), \"b\")\n    {:ok, \"b\"}\n\n    iex(8)> parse_string(char_parser([\"b\", \"c\"]), \"b\")\n    {:ok, \"b\"}\n\n\n    iex(9)> parse_string(char_parser([\"b\", \"c\"]), \"a\")\n    {:error, \"a not member of \\\"bc\\\" in char_parser([\\\"b\\\", \\\"c\\\"])  :1,1\"}\n\nOften used charsets might be extremly large to be defined and therefore some more specialised parsers have been defined:\n\n##","ref":"Minipeg.html#module-parsing-single-characters"},{"type":"module","title":"Parsing POSIX character classes - Minipeg","doc":"If instead of a string or list we pass an atom into `char_parser` it only parses a character if it matches a character class as defined in POSIX regular expressions,\nwhich are also described in the docs of the [`Regex`](https://hexdocs.pm/elixir/Regex.html#module-character-classes) module, here are the currently supported values:\n\n```\n  :alnum | :alpha | :blank | :cntrl | :digit | :graph | :lower | :print | :punct | :space | :upper | :word | :xdigit\n```\n\n    iex(10)> parser = char_parser(:alnum)\n    ...(10)> \"aD7_%\"\n    ...(10)> |> String.graphemes\n    ...(10)> |> Enum.map(&parse_string(parser, &1))\n    [\n      ok: \"a\",\n      ok: \"D\",\n      ok: \"7\",\n      error: \"~r{\\\\A[[:alnum:]]}u does not match at 1,1 in char_parser(:alnum)  :1,1\",\n      error: \"~r{\\\\A[[:alnum:]]}u does not match at 1,1 in char_parser(:alnum)  :1,1\"\n    ]\n\n\n#### `escaped_char_parser`\n\nthis parser helps to parse escaped characters, while one could de this quite easily with the following example, one notices\nthat in order to get just an escpaed character two combinators, `map` and `sequence` are needed\n\n    iex(11)> escaped_quote_parser = sequence([\n    ...(11)> char_parser(\"\\\\\"), char_parser()])\n    ...(11)> |> map(&Enum.at(&1, 1))\n    ...(11)> { parse_string(escaped_quote_parser, \"\\\\\\\"\"), parse_string(escaped_quote_parser, \"\\\\'\") }\n    { {:ok, \"\\\"\"}, {:ok, \"'\"} }\n\nCompare this to the provided `escaped_char_parser`:\n\n    iex(12)> parse_string(escaped_char_parser(), \"\\\\a\")\n    {:ok, \"a\"}\n\nWe can also change the escape character\n\n    iex(13)> parse_string(escaped_char_parser(\"%\"), \"%a\")\n    {:ok, \"a\"}\n\n    iex(14)> parse_string(escaped_char_parser(\"%\"), \"\\\\a\")\n    {:error, \"\\\\ not member of \\\"%\\\" in char_parser(\\\"%\\\") in escaped_char_parser(%)  :1,1\"}\n\nAnd furthermore we can restrict the set of which characters are allowed to be escaped\n\n    iex(15)> parser = escaped_char_parser(\"\\\\\", \"escape only \\\\\", \"\\\\\")\n    ...(15)> { parse_string(parser, \"\\\\\\\\\"), parse_string(parser, \"\\\\a\") }\n    { {:ok, \"\\\\\"}, {:error, \"a not member of \\\"\\\\\\\\\\\" in char_parser(\\\"\\\\\\\\\\\") in escape only \\\\  :1,1\"} }\n\n#","ref":"Minipeg.html#module-parsing-posix-character-classes"},{"type":"module","title":"Parsing sequences of characters - Minipeg","doc":"##","ref":"Minipeg.html#module-parsing-sequences-of-characters"},{"type":"module","title":"Keywords: `keywords_parser` - Minipeg","doc":"Does pretty much what is expected ;)\n\n    iex(16)> kwd_parser = keywords_parser([\"do\", \"else\", \"if\"])\n    ...(16)> [\"do\", \"if\", \"for\"]\n    ...(16)> |> Enum.map(&parse_string(kwd_parser, &1))\n    [\n      ok: \"do\",\n      ok: \"if\",\n      error: \"no alternative could be parsed in keywords_parser([\\\"do\\\", \\\"else\\\", \\\"if\\\"])  :1,1\"\n    ]\n\n##","ref":"Minipeg.html#module-keywords-keywords_parser"},{"type":"module","title":"Identifiers: `ident_parser` - Minipeg","doc":"An identifier is defined by a character class for its first character and a character class for its subsequent characters, so\none could define it roughly as\n\n        sequence([\n          first_char_parser,\n          many(second_char_paser)])\n\nAnd that is how the `ident_parser` is actually defined\n\n    iex(17)> parse_string(ident_parser(), \"hello_42\")\n    {:ok, \"hello_42\"}\n\n    iex(18)> parse_string(ident_parser(), \"42hello_world\")\n    {:error, \"~r{\\\\A[[:alpha:]]}u does not match at 1,1 in char_parser(:alpha) in sequence  :1,1\"}\n\n\nIn Lisp we prefer `-` to `_`, no problem\n\n    iex(19)> parse_string(ident_parser(\"Lisp Style\", additional_chars: \"-\"), \"hello-42\")\n    {:ok, \"hello-42\"}\n\nBut even the parser for the first character and the following characters can be defined\n\n        iex(20)> register_parser = ident_parser(\n        ...(20)>   \"Uppercase and digit\",\n        ...(20)>   first_char_parser: char_parser(:upper),\n        ...(20)>   rest_char_parser: char_parser(:digit),\n        ...(20)>   additional_chars: nil,\n        ...(20)>   max_len: 2,\n        ...(20)>   min_len: 2)\n        ...(20)> [\n        ...(20)>   parse_string(register_parser, \"R2\"),\n        ...(20)>   parse_string(register_parser, \"X_\"),\n        ...(20)>   parse_string(register_parser, \"R12\"),\n        ...(20)>   parse_string(register_parser, \"a2\"),\n        ...(20)>   parse_string(register_parser, \"ab\")\n        ...(20)> ]\n        [\n          ok: \"R2\",\n          error: \"string \\\"X\\\" length 1 under required minimum 2  :1,1\",\n          error: \"string \\\"R12\\\" length 3 exceeds allowed 2  :1,1\",\n          error: \"~r{\\\\A[[:upper:]]}u does not match at 1,1 in char_parser(:upper) in sequence  :1,1\",\n          error: \"~r{\\\\A[[:upper:]]}u does not match at 1,1 in char_parser(:upper) in sequence  :1,1\"\n        ]\n\nIn some environments we would like to restrict the length of an identifier\n\n        iex(21)> dos_name_parser = ident_parser(\"dos name parser\", max_len: 8)\n        ...(21)> [\n        ...(21)>   parse_string(dos_name_parser, \"dosok\"),\n        ...(21)>   parse_string(dos_name_parser, \"way_too_long\")\n        ...(21)> ]\n        [\n          ok: \"dosok\",\n          error: \"string \\\"way_too_long\\\" length 12 exceeds allowed 8  :1,1\"\n        ]\n\n        }\n#","ref":"Minipeg.html#module-identifiers-ident_parser"},{"type":"module","title":"Regex Parsers - Minipeg","doc":"Sometimes it is cumbersome to specify a parser that can be expressed simply with a regular expression.\nA good example of this would be the `ident_parser` from above.\n\nA _Regex Parser_ will always create an anchored regex which will be parsed against the start of the input.\nAs long as you avoid backtracking or unbond lookahead the performance should be at the same level as \nwriting a parser \"by hand\".\n\nThe `Regex` that will be used in the parser will be compiled as fomllows from the string parameter specifying\nit:\n\n        Regex.compile!(\"\\\\A\" <> param, [:unicode])\n\n#### `rgx_parser`\n\nThis is the basic parser that creates a regular expression as described above and if it parses puts the result of\n`Regex.run(compiled_rgx, input.input)` into the ast field of the `Success` structure, of course the matching string is\nremoved from the returned input\n\n\n      iex(22)> atom_parser = rgx_parser(\":[[:alpha:]][[:word:]]*\", \"rgx based atom parser\")\n      ...(22)> Parser.parse(atom_parser, Input.new(\":atom_42\"), %Cache{})\n      %Success{ast: [\":atom_42\"], cache: %Cache{}, rest: %Input{col: 9, context: %{}, input: \"\", lnb: 1}}\n\n      iex(23)> atom_parser = rgx_parser(\":[[:alpha:]][[:word:]]*\", \"rgx based atom parser\")\n      ...(23)> parse_string(atom_parser, \"hello\")\n      {:error, \"~r{\\\\A:[[:alpha:]][[:word:]]*}u does not match at 1,1 in rgx based atom parser  :1,1\"}\n\n#### `rgx_match_parser`\n\n Oftentimes we will only want the whole match and do not care of captures, enter `rgx_match_parser`\n\n      iex(24)> atom_parser = rgx_match_parser(\":[[:alpha:]][[:word:]]*\", \"rgx based atom parser\")\n      ...(24)> Parser.parse(atom_parser, Input.new(\":atom_42\"), %Cache{})\n      %Success{ast: \":atom_42\", cache: %Cache{}, rest: %Input{col: 9, context: %{}, input: \"\", lnb: 1}}\n\nThe `:unicode` will **always** be used in the compiled regex, however one can add other options\nA nice addition is the `:extended` option\n\n      iex(25)> a_list_parser = rgx_match_parser(\" a (?: , a)+ \", nil, [:extended])\n      ...(25)> parse_string(a_list_parser, \"a,a,abc\")\n      {:ok, \"a,a,a\"}\n\n\n#### `rgx_capture_parser`\n\nAlso quite often we are only interested in one capture\n\n      iex(26)> number_parser = rgx_capture_parser(\"\\\\s*(\\\\d+)\") |> map(&String.to_integer/1)\n      ...(26)> parse_string(number_parser, \"  42\")\n      {:ok, 42}","ref":"Minipeg.html#module-regex-parsers"},{"type":"module","title":"Essential Combinators - Minipeg","doc":"### `many`\n\nParses an input if a parser can be applied _many_ times to it. This means that `many` can parse\nan _empty_ input unless a minimum count is specified:\n\n    iex(27)> a_parser = many(char_parser(\"a\"))\n    ...(27)> assert parse_string(a_parser, \"\") == {:ok, []}\n    ...(27)> assert parse_string(a_parser, \"aaa\") == {:ok, ~W[a a a]}\n\nBut if we specify a `min_count`...\n\n    iex(28)> a_parser = many(char_parser(\"a\"), \"at least one\", 1)\n    ...(28)> assert parse_string(a_parser, \"\") == {:error, \"Missing 1 parses in many in at least one  :1,1\"}\n    ...(28)> assert parse_string(a_parser, \"aaa\") == {:ok, ~W[a a a]}\n\n### `sequence`\n\nTakes a list of `Parsers`, only parses if **all** of them parse subsequently on the given\ninput and return a list of the results of each parser.\n\nLet us _remimplement_ the keywords parser\n\n    iex(29)> if_parser = sequence([char_parser(\"i\"), char_parser(\"f\")])\n    ...(29)> |> map(&Enum.join/1)\n    ...(29)> ~w[if else]\n    ...(29)> |> Enum.map(&parse_string(if_parser, &1))\n    [\n      ok: \"if\",\n        error: \"e not member of \\\"i\\\" in char_parser(\\\"i\\\") in sequence  :1,1\"\n    ]\n\nThis leads us directly to\n\n### `map`\n\nMap, takes a parser and a _mapping function_. It returns a new parser that fails with exactly\nthe same error message as its input parser, but succeeds with the result mapped by the _mapping function_.\n\n    iex(30)> list_parser = many(char_parser()) |> map(&Enum.join(&1, \", \"))\n    ...(30)> parse_string(list_parser, \"abc\")\n    {:ok, \"a, b, c\"}\n\nOftentimes we will want the position of a parsed string to be included into the ast.\nAn _obvious_ use case to identify where in the source a semantic error has occurred.\n\nEnter ... \n\n#### `mapp`\n\nThis example also demonstrates the `ignore` combinator which will be ignored in `sequence`\n\n      iex(31)> a_parser = sequence([ws_parser() |> ignore(), char_parser(\"a\") |> mapp(&{&1, &2})])\n      ...(31)> [parse_string(a_parser, \"  a\"), parse_string(a_parser, \"\")]\n      [\n        ok: [{\"a\", {3, 1}}],\n        error: \"encountered end of input in char_parser(\\\"a\\\") in sequence  :1,1\"\n      ]\n\n`ignore` does of course not mean that the input does not need to parse\n\n\n      iex(32)> a_parser = sequence([char_parser(\"b\") |> ignore(), char_parser(\"a\") |> mapp(&{&1, &2})])\n      ...(32)> parse_string(a_parser, \"a\")\n      {\n        :error, \"a not member of \\\"b\\\" in char_parser(\\\"b\\\") in sequence  :1,1\"\n      }\n\n\nIt is also quite normal to just append the position to the ast, so the above can also be written simpler\nwith ...\n\n#### `with_pos`\n\n      iex(33)> a_parser = sequence([ws_parser() |> ignore(), char_parser(\"a\") |> with_pos()])\n      ...(33)> [parse_string(a_parser, \"  a\"), parse_string(a_parser, \"\")]\n      {\n        :ok, {\"a\", {3, 1}}\n      }\n\n### `select`\n\nOftentimes `select` is (maybe better) named `choice` we have therefore define an alias for `choice`\n\n      iex(34)> vowel_parser = select(~W[a e i o u y] |> Enum.map(&char_parser/1), \"vowel_parser\")\n      ...(34)> ~W[a u y x] |> Enum.map(&parse_string(vowel_parser, &1))\n      [\n        ok: \"a\",\n        ok: \"u\",\n        ok: \"y\",\n        error: \"no alternative could be parsed in vowel_parser  :1,1\"\n      ]\n\nAnd the aliased `option`\n\n    iex(35)> parser = option([char_parser(\"a\"), char_parser(\"b\")], \"option_parser\")\n    ...(35)> ~W[b x] |> Enum.map(&parse_string(parser, &1))\n    [\n      ok: \"b\",\n      error: \"no alternative could be parsed in option_parser  :1,1\"\n    ]\n  \nend\n\n### `many_sel`\n\nJust a shortcut for `many(select(...`\n\n    iex(36)> parser = many_sel([char_parser(\"a\"), char_parser(\"b\")])\n    ...(36)> parse_string(parser, \"abba\")\n    {:ok, ~W[a b b a]}\n\n\n### `many_seq`\n\nJust a shortcut for `many(sequence(...`\n\n    iex(37)> parser = many_seq([char_parser(\"a\"), char_parser(\"b\")])\n    ...(37)> parse_string(parser, \"abab\")\n    {:ok, [~W[a b], ~W[a b]]}\n\nIn the result we can see that it is important to take into consideration that this\nis indeed two nested parsers and one will often do things as the following\n\n    iex(38)> parser = many_seq([char_parser(\"a\"), char_parser(\"b\")]) |> map(&IO.chardata_to_string/1)\n    ...(38)> parse_string(parser, \"abab\")\n    {:ok, \"abab\"}","ref":"Minipeg.html#module-essential-combinators"},{"type":"module","title":"Convenience Combinators - Minipeg","doc":"#","ref":"Minipeg.html#module-convenience-combinators"},{"type":"module","title":"What about whitespace - Minipeg","doc":"Oftentimes whitespace shall be ignored in the resulting ast, and sometimes in the input too. To be more precise\nwhen whitespace stops parsing of example a keyword then the subsequent patser often is not interested in$\nthe left ofer ws preceeding its new input.\n\nEnter `ignore_ws`\n\nHere is the form that does not ignore newlines, which is the default:\n    iex(39)> next_char_parser = ignore_ws(char_parser())\n    ...(39)> parse_string(next_char_parser, \" \\ta\")\n    {:ok, \"a\"}\n\n    iex(40)> next_a_parser = ignore_ws(char_parser(\"a\"))\n    ...(40)> parse_string(next_a_parser, \" \\na\")\n    {:error, \"\\n not member of \\\"a\\\" in char_parser(\\\"a\\\")  :1,2\"}\n\nBut we can also use the newline allowing version\n\n    iex(41)> next_a_parser = ignore_ws(char_parser(\"a\"), \"skip newlines\", true)\n    ...(41)> parse_string(next_a_parser, \" \\na\")\n    {:ok, \"a\"}\n\n\n### `upto_parser_parser`\n\nOftentimes parsing algorithms become more read- and maintanable when we reparse a part of the\ninput stream with a different parser. In order to be able to do this we can just parse up to\na part of the input stream defined by a parser and return the input stream up to that point\nas a `String`\n\n**N.B.** This convenience comes with a price, the `parser` will try to match for every position\nin the input stream until it succeeds or fails on an empty input. Hence use with care.\n\n    iex(42)> upto_end_parser = upto_parser_parser(keywords_parser(~W[end]))\n    ...(42)> parse_string(upto_end_parser, \"up to end\")\n    {:ok, \"up to \"}\n\nIf however `parser` never succeeds the `upto_parser_parser` fails.\n\n    iex(43)> upto_end_parser = upto_parser_parser(keywords_parser(~W[end]))\n    ...(43)> parse_string(upto_end_parser, \"up to en\")\n    {:error, \"encountered end of input in upto_parser_parser(keywords_parser([\\\"end\\\"]), keep)  :1,9\"}\n\nWe can also ask to include the ast from the `parser` into the result\n\n    iex(44)> upto_end_parser = upto_parser_parser(keywords_parser(~W[end]), \"my parser\", :include)\n    ...(44)> parse_string(upto_end_parser, \"up to end\")\n    {:ok, {\"up to \", \"end\"}}\n\nOr to discard it, which is not the default case (which is `:keep`)\n\n    iex(45)> keep_parser = upto_parser_parser(keywords_parser(~W[end]), \"my parser\", :keep)\n    ...(45)> discard_parser = upto_parser_parser(keywords_parser(~W[end]), \"my other parser\", :discard)\n    ...(45)> [ parse(keep_parser, \"up to end\"), parse(discard_parser, \"up to end\")]\n    [\n      %Minipeg.Success{ast: \"up to \", cache: %Minipeg.Cache{cache: %{}}, parsed_at: {7, 1}, rest: %Minipeg.Input{input: \"end\", col: 7, lnb: 1}},\n      %Minipeg.Success{ast: \"up to \", cache: %Minipeg.Cache{cache: %{}}, parsed_at: {7, 1}, rest: %Minipeg.Input{input: \"\", col: 10, lnb: 1}}\n    ]","ref":"Minipeg.html#module-what-about-whitespace"},{"type":"module","title":"Definitions - Minipeg","doc":"#","ref":"Minipeg.html#module-definitions"},{"type":"module","title":"Parser - Minipeg","doc":"A `Parser` is a struct that parses an `Input` struct (with the `parse` function) and either returns a `Success` or `Failure` struct\n\nIn order to abstract the internal representations of input and results  the `parse_string` function is provided as shown in the exampleas above.\n\nThe `Success` struct contains the resulting Abstract Syntaxt Tree and the rest of the input as an `Input` struct.\n\nThe `Failure` struct contains the original `Input` struct and an error message\n\nInternally a `Cache` is already returned (and passed into subsequent `parse` calls of the `Parser` module) but unless\nyou are extending `Minipeg` itself by defining parsers by hand instead of using `Combinators` you can ignore this.\n\n#","ref":"Minipeg.html#module-parser"},{"type":"module","title":"Combinator - Minipeg","doc":"A `Combibator` is a function that takes a `Parser` optionally some arguments and returns a new `Parser`","ref":"Minipeg.html#module-combinator"},{"type":"module","title":"Minipeg.Cache","doc":"Wrapping a map","ref":"Minipeg.Cache.html"},{"type":"function","title":"Minipeg.Cache.empty/0","doc":"","ref":"Minipeg.Cache.html#empty/0"},{"type":"function","title":"Minipeg.Cache.lookup/3","doc":"","ref":"Minipeg.Cache.html#lookup/3"},{"type":"function","title":"Minipeg.Cache.new/3","doc":"","ref":"Minipeg.Cache.html#new/3"},{"type":"function","title":"Minipeg.Cache.update/4","doc":"","ref":"Minipeg.Cache.html#update/4"},{"type":"type","title":"Minipeg.Cache.ast_list_t/0","doc":"","ref":"Minipeg.Cache.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Cache.ast_t/0","doc":"","ref":"Minipeg.Cache.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Cache.binaries/0","doc":"","ref":"Minipeg.Cache.html#t:binaries/0"},{"type":"type","title":"Minipeg.Cache.binary?/0","doc":"","ref":"Minipeg.Cache.html#t:binary?/0"},{"type":"type","title":"Minipeg.Cache.char_set_t/0","doc":"","ref":"Minipeg.Cache.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Cache.either/2","doc":"","ref":"Minipeg.Cache.html#t:either/2"},{"type":"type","title":"Minipeg.Cache.entry_t/0","doc":"","ref":"Minipeg.Cache.html#t:entry_t/0"},{"type":"type","title":"Minipeg.Cache.input_t/0","doc":"","ref":"Minipeg.Cache.html#t:input_t/0"},{"type":"type","title":"Minipeg.Cache.maybe/1","doc":"","ref":"Minipeg.Cache.html#t:maybe/1"},{"type":"type","title":"Minipeg.Cache.parser_function_t/0","doc":"","ref":"Minipeg.Cache.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Cache.position_t/0","doc":"","ref":"Minipeg.Cache.html#t:position_t/0"},{"type":"type","title":"Minipeg.Cache.result_t/0","doc":"","ref":"Minipeg.Cache.html#t:result_t/0"},{"type":"type","title":"Minipeg.Cache.satisfier_result_t/0","doc":"","ref":"Minipeg.Cache.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Cache.satisfier_t/0","doc":"","ref":"Minipeg.Cache.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Cache.storage_t/0","doc":"","ref":"Minipeg.Cache.html#t:storage_t/0"},{"type":"type","title":"Minipeg.Cache.str_or_count_t/0","doc":"","ref":"Minipeg.Cache.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Cache.t/0","doc":"","ref":"Minipeg.Cache.html#t:t/0"},{"type":"module","title":"Minipeg.Combinators","doc":"All public functions in this module take a parser and potentially more parameters and\nreturn a new parser","ref":"Minipeg.Combinators.html"},{"type":"function","title":"Minipeg.Combinators.debug/2","doc":"Just parses with `parser` but displays, input and result to stderr","ref":"Minipeg.Combinators.html#debug/2"},{"type":"function","title":"Minipeg.Combinators.ignore/2","doc":"","ref":"Minipeg.Combinators.html#ignore/2"},{"type":"function","title":"Minipeg.Combinators.ignore_ws/3","doc":"Parsers a string that would be parsed by parser but ignoring leading whitespace, if you also want to\nignore whitespace after the parsed string use `tokenized`","ref":"Minipeg.Combinators.html#ignore_ws/3"},{"type":"function","title":"Minipeg.Combinators.in_between_parser/4","doc":"","ref":"Minipeg.Combinators.html#in_between_parser/4"},{"type":"function","title":"Minipeg.Combinators.lazy/2","doc":"Unwrapps a wrapped parser and parses with it","ref":"Minipeg.Combinators.html#lazy/2"},{"type":"function","title":"Minipeg.Combinators.list_parser/4","doc":"Parses a list defined by an `element_parser` and a `seperator_parser`","ref":"Minipeg.Combinators.html#list_parser/4"},{"type":"function","title":"Minipeg.Combinators.many/3","doc":"Applies a parser as many times as possible, can use `min_count` (defaulting to 0) to\nfail unless the parser could parse `min_count` times","ref":"Minipeg.Combinators.html#many/3"},{"type":"function","title":"Minipeg.Combinators.many_sel/3","doc":"","ref":"Minipeg.Combinators.html#many_sel/3"},{"type":"function","title":"Minipeg.Combinators.many_seq/3","doc":"","ref":"Minipeg.Combinators.html#many_seq/3"},{"type":"function","title":"Minipeg.Combinators.map/3","doc":"Succeeds if `parser` succeeds, but maps the ast with `mapper_fun`.\nIf `parser` fails, it just fails","ref":"Minipeg.Combinators.html#map/3"},{"type":"function","title":"Minipeg.Combinators.map_to_string/2","doc":"parses iff `parser` parses then maps the ast to a string with `IO.chardata_to_string/1`\nThe ast must therefore be of type `IO data`","ref":"Minipeg.Combinators.html#map_to_string/2"},{"type":"function","title":"Minipeg.Combinators.mapp/3","doc":"This also provides a second argument, the position in form of a tuple `{col, lnb}`\nto the mapper function","ref":"Minipeg.Combinators.html#mapp/3"},{"type":"function","title":"Minipeg.Combinators.maybe/2","doc":"","ref":"Minipeg.Combinators.html#maybe/2"},{"type":"function","title":"Minipeg.Combinators.option/2","doc":"","ref":"Minipeg.Combinators.html#option/2"},{"type":"function","title":"Minipeg.Combinators.satisfy/3","doc":"Returns a parser that only succeeds if the original parser succeeds **and**\nthe satisfier function that is called with the ast of the original result\nreturns {:ok, value}. It also changes the original ast with value in the\nfinal result.","ref":"Minipeg.Combinators.html#satisfy/3"},{"type":"function","title":"Minipeg.Combinators.savepoint/3","doc":"Looks into the cache (for this parsing position) before parsing,\nif no result found parses and puts the result into the cache (for this parsing position)","ref":"Minipeg.Combinators.html#savepoint/3"},{"type":"function","title":"Minipeg.Combinators.select/2","doc":"","ref":"Minipeg.Combinators.html#select/2"},{"type":"function","title":"Minipeg.Combinators.sequence/2","doc":"","ref":"Minipeg.Combinators.html#sequence/2"},{"type":"function","title":"Minipeg.Combinators.tokenize/1","doc":"","ref":"Minipeg.Combinators.html#tokenize/1"},{"type":"function","title":"Minipeg.Combinators.upto_parser_parser/3","doc":"Consume chars until `parser` parses and return them as parsed ast, fails if parser never succeeds\ncan add the delimiter to the ast or leave it on the input stream","ref":"Minipeg.Combinators.html#upto_parser_parser/3"},{"type":"function","title":"Minipeg.Combinators.with_pos/2","doc":"A shortcut for `mapp(parser, &{&1, &2}...`","ref":"Minipeg.Combinators.html#with_pos/2"},{"type":"type","title":"Minipeg.Combinators.ast_list_t/0","doc":"","ref":"Minipeg.Combinators.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Combinators.ast_t/0","doc":"","ref":"Minipeg.Combinators.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Combinators.binaries/0","doc":"","ref":"Minipeg.Combinators.html#t:binaries/0"},{"type":"type","title":"Minipeg.Combinators.binary?/0","doc":"","ref":"Minipeg.Combinators.html#t:binary?/0"},{"type":"type","title":"Minipeg.Combinators.char_set_t/0","doc":"","ref":"Minipeg.Combinators.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Combinators.either/2","doc":"","ref":"Minipeg.Combinators.html#t:either/2"},{"type":"type","title":"Minipeg.Combinators.input_t/0","doc":"","ref":"Minipeg.Combinators.html#t:input_t/0"},{"type":"type","title":"Minipeg.Combinators.maybe/1","doc":"","ref":"Minipeg.Combinators.html#t:maybe/1"},{"type":"type","title":"Minipeg.Combinators.parser_function_t/0","doc":"","ref":"Minipeg.Combinators.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Combinators.position_t/0","doc":"","ref":"Minipeg.Combinators.html#t:position_t/0"},{"type":"type","title":"Minipeg.Combinators.result_t/0","doc":"","ref":"Minipeg.Combinators.html#t:result_t/0"},{"type":"type","title":"Minipeg.Combinators.satisfier_result_t/0","doc":"","ref":"Minipeg.Combinators.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Combinators.satisfier_t/0","doc":"","ref":"Minipeg.Combinators.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Combinators.str_or_count_t/0","doc":"","ref":"Minipeg.Combinators.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Combinators.wrapped_parser_t/0","doc":"","ref":"Minipeg.Combinators.html#t:wrapped_parser_t/0"},{"type":"module","title":"Minipeg.Failure","doc":"A failure result","ref":"Minipeg.Failure.html"},{"type":"function","title":"Minipeg.Failure.fail/3","doc":"","ref":"Minipeg.Failure.html#fail/3"},{"type":"function","title":"Minipeg.Failure.format/1","doc":"","ref":"Minipeg.Failure.html#format/1"},{"type":"type","title":"Minipeg.Failure.t/0","doc":"","ref":"Minipeg.Failure.html#t:t/0"},{"type":"module","title":"Minipeg.Ignore","doc":"An ignored success result","ref":"Minipeg.Ignore.html"},{"type":"function","title":"Minipeg.Ignore.ignore/2","doc":"","ref":"Minipeg.Ignore.html#ignore/2"},{"type":"type","title":"Minipeg.Ignore.ast_list_t/0","doc":"","ref":"Minipeg.Ignore.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Ignore.ast_t/0","doc":"","ref":"Minipeg.Ignore.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Ignore.binaries/0","doc":"","ref":"Minipeg.Ignore.html#t:binaries/0"},{"type":"type","title":"Minipeg.Ignore.binary?/0","doc":"","ref":"Minipeg.Ignore.html#t:binary?/0"},{"type":"type","title":"Minipeg.Ignore.char_set_t/0","doc":"","ref":"Minipeg.Ignore.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Ignore.either/2","doc":"","ref":"Minipeg.Ignore.html#t:either/2"},{"type":"type","title":"Minipeg.Ignore.input_t/0","doc":"","ref":"Minipeg.Ignore.html#t:input_t/0"},{"type":"type","title":"Minipeg.Ignore.maybe/1","doc":"","ref":"Minipeg.Ignore.html#t:maybe/1"},{"type":"type","title":"Minipeg.Ignore.parser_function_t/0","doc":"","ref":"Minipeg.Ignore.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Ignore.position_t/0","doc":"","ref":"Minipeg.Ignore.html#t:position_t/0"},{"type":"type","title":"Minipeg.Ignore.result_t/0","doc":"","ref":"Minipeg.Ignore.html#t:result_t/0"},{"type":"type","title":"Minipeg.Ignore.satisfier_result_t/0","doc":"","ref":"Minipeg.Ignore.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Ignore.satisfier_t/0","doc":"","ref":"Minipeg.Ignore.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Ignore.str_or_count_t/0","doc":"","ref":"Minipeg.Ignore.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Ignore.t/0","doc":"","ref":"Minipeg.Ignore.html#t:t/0"},{"type":"module","title":"Minipeg.Input","doc":"An input wrapper","ref":"Minipeg.Input.html"},{"type":"function","title":"Minipeg.Input.drop/2","doc":"","ref":"Minipeg.Input.html#drop/2"},{"type":"function","title":"Minipeg.Input.new/4","doc":"","ref":"Minipeg.Input.html#new/4"},{"type":"function","title":"Minipeg.Input.position/1","doc":"","ref":"Minipeg.Input.html#position/1"},{"type":"function","title":"Minipeg.Input.report_position/2","doc":"","ref":"Minipeg.Input.html#report_position/2"},{"type":"function","title":"Minipeg.Input.take/2","doc":"","ref":"Minipeg.Input.html#take/2"},{"type":"type","title":"Minipeg.Input.ast_list_t/0","doc":"","ref":"Minipeg.Input.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Input.ast_t/0","doc":"","ref":"Minipeg.Input.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Input.binaries/0","doc":"","ref":"Minipeg.Input.html#t:binaries/0"},{"type":"type","title":"Minipeg.Input.binary?/0","doc":"","ref":"Minipeg.Input.html#t:binary?/0"},{"type":"type","title":"Minipeg.Input.char_set_t/0","doc":"","ref":"Minipeg.Input.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Input.either/2","doc":"","ref":"Minipeg.Input.html#t:either/2"},{"type":"type","title":"Minipeg.Input.input_t/0","doc":"","ref":"Minipeg.Input.html#t:input_t/0"},{"type":"type","title":"Minipeg.Input.maybe/1","doc":"","ref":"Minipeg.Input.html#t:maybe/1"},{"type":"type","title":"Minipeg.Input.parser_function_t/0","doc":"","ref":"Minipeg.Input.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Input.position_t/0","doc":"","ref":"Minipeg.Input.html#t:position_t/0"},{"type":"type","title":"Minipeg.Input.result_t/0","doc":"","ref":"Minipeg.Input.html#t:result_t/0"},{"type":"type","title":"Minipeg.Input.satisfier_result_t/0","doc":"","ref":"Minipeg.Input.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Input.satisfier_t/0","doc":"","ref":"Minipeg.Input.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Input.str_or_count_t/0","doc":"","ref":"Minipeg.Input.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Input.t/0","doc":"","ref":"Minipeg.Input.html#t:t/0"},{"type":"type","title":"Minipeg.Input.take_and_rest_t/0","doc":"","ref":"Minipeg.Input.html#t:take_and_rest_t/0"},{"type":"module","title":"Minipeg.Mappers","doc":"Define some useful functions for `Minipeg.Combinators.map`","ref":"Minipeg.Mappers.html"},{"type":"function","title":"Minipeg.Mappers.ignore_first/1","doc":"A mapper for parsers that return not empty lists, it removes the first element from the mapper\n\nEx.:\n  \n        sequence([\n          char_parser(\"%\"),\n          some_parser()        # --> some_ast\n        ]) |> map(&ignore_first/1) # --> [some_ast]\n\n        sequence([\n          char_parser(\"%\"),\n          some_parser()        # --> some_ast\n          other_parser()        # --> other_ast\n        ]) |> map(&ignore_first/1) # --> [some_ast, other_ast]","ref":"Minipeg.Mappers.html#ignore_first/1"},{"type":"function","title":"Minipeg.Mappers.ignore_first_and_flatten/1","doc":"A mapper for parsers that return not empty lists, it removes the first element from the mapper\nand then flattens the rest\n\nEx.:\n        sequence([\n          char_parser(\"%\"),\n          sequence([\n          some_parser()        # --> some_ast\n          other_parser()        # --> other_ast\n          ])\n        ]) |> map(&ignore_first/1) # --> [some_ast, other_ast] and not [[..., ...]]","ref":"Minipeg.Mappers.html#ignore_first_and_flatten/1"},{"type":"type","title":"Minipeg.Mappers.ast_list_t/0","doc":"","ref":"Minipeg.Mappers.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Mappers.ast_t/0","doc":"","ref":"Minipeg.Mappers.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Mappers.binaries/0","doc":"","ref":"Minipeg.Mappers.html#t:binaries/0"},{"type":"type","title":"Minipeg.Mappers.binary?/0","doc":"","ref":"Minipeg.Mappers.html#t:binary?/0"},{"type":"type","title":"Minipeg.Mappers.char_set_t/0","doc":"","ref":"Minipeg.Mappers.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Mappers.either/2","doc":"","ref":"Minipeg.Mappers.html#t:either/2"},{"type":"type","title":"Minipeg.Mappers.input_t/0","doc":"","ref":"Minipeg.Mappers.html#t:input_t/0"},{"type":"type","title":"Minipeg.Mappers.maybe/1","doc":"","ref":"Minipeg.Mappers.html#t:maybe/1"},{"type":"type","title":"Minipeg.Mappers.parser_function_t/0","doc":"","ref":"Minipeg.Mappers.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Mappers.position_t/0","doc":"","ref":"Minipeg.Mappers.html#t:position_t/0"},{"type":"type","title":"Minipeg.Mappers.result_t/0","doc":"","ref":"Minipeg.Mappers.html#t:result_t/0"},{"type":"type","title":"Minipeg.Mappers.satisfier_result_t/0","doc":"","ref":"Minipeg.Mappers.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Mappers.satisfier_t/0","doc":"","ref":"Minipeg.Mappers.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Mappers.str_or_count_t/0","doc":"","ref":"Minipeg.Mappers.html#t:str_or_count_t/0"},{"type":"module","title":"Minipeg.Parser","doc":"A struct containung a parser function and a name","ref":"Minipeg.Parser.html"},{"type":"function","title":"Minipeg.Parser.new/2","doc":"","ref":"Minipeg.Parser.html#new/2"},{"type":"function","title":"Minipeg.Parser.parse/3","doc":"","ref":"Minipeg.Parser.html#parse/3"},{"type":"function","title":"Minipeg.Parser.parse_string/2","doc":"","ref":"Minipeg.Parser.html#parse_string/2"},{"type":"type","title":"Minipeg.Parser.ast_list_t/0","doc":"","ref":"Minipeg.Parser.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Parser.ast_t/0","doc":"","ref":"Minipeg.Parser.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Parser.binaries/0","doc":"","ref":"Minipeg.Parser.html#t:binaries/0"},{"type":"type","title":"Minipeg.Parser.binary?/0","doc":"","ref":"Minipeg.Parser.html#t:binary?/0"},{"type":"type","title":"Minipeg.Parser.char_set_t/0","doc":"","ref":"Minipeg.Parser.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Parser.either/2","doc":"","ref":"Minipeg.Parser.html#t:either/2"},{"type":"type","title":"Minipeg.Parser.input_t/0","doc":"","ref":"Minipeg.Parser.html#t:input_t/0"},{"type":"type","title":"Minipeg.Parser.maybe/1","doc":"","ref":"Minipeg.Parser.html#t:maybe/1"},{"type":"type","title":"Minipeg.Parser.parser_function_t/0","doc":"","ref":"Minipeg.Parser.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Parser.position_t/0","doc":"","ref":"Minipeg.Parser.html#t:position_t/0"},{"type":"type","title":"Minipeg.Parser.result_t/0","doc":"","ref":"Minipeg.Parser.html#t:result_t/0"},{"type":"type","title":"Minipeg.Parser.result_tuple_t/1","doc":"","ref":"Minipeg.Parser.html#t:result_tuple_t/1"},{"type":"type","title":"Minipeg.Parser.satisfier_result_t/0","doc":"","ref":"Minipeg.Parser.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Parser.satisfier_t/0","doc":"","ref":"Minipeg.Parser.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Parser.str_or_count_t/0","doc":"","ref":"Minipeg.Parser.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Parser.t/0","doc":"","ref":"Minipeg.Parser.html#t:t/0"},{"type":"module","title":"Minipeg.Parsers","doc":"A collection of basic parsers","ref":"Minipeg.Parsers.html"},{"type":"function","title":"Minipeg.Parsers.char_parser/2","doc":"Parses any character in the specified set, defaulting to all characters\n\nSucceeds if next char in input is in the specified set\nFails if input is empty or next char is not in the specified set\n\nIf the specified charset is an atom it is interpreted as a POSIX character class\ndescribed in the docs of the `Regex` module, here are the currently supported values:\n\n```\n  :alnum | :alpha | :blank | :cntrl | :digit | :graph | :lower | :print | :punct | :space | :upper | :word | :xdigit\n```","ref":"Minipeg.Parsers.html#char_parser/2"},{"type":"function","title":"Minipeg.Parsers.delimited_string_parser/4","doc":"","ref":"Minipeg.Parsers.html#delimited_string_parser/4"},{"type":"function","title":"Minipeg.Parsers.end_parser/1","doc":"Parser that only succeeds on empty input / end of input","ref":"Minipeg.Parsers.html#end_parser/1"},{"type":"function","title":"Minipeg.Parsers.escaped_char_parser/3","doc":"parses an escape char and then any char","ref":"Minipeg.Parsers.html#escaped_char_parser/3"},{"type":"function","title":"Minipeg.Parsers.failure_parser/2","doc":"This parser always fails","ref":"Minipeg.Parsers.html#failure_parser/2"},{"type":"function","title":"Minipeg.Parsers.ident_parser/2","doc":"","ref":"Minipeg.Parsers.html#ident_parser/2"},{"type":"function","title":"Minipeg.Parsers.int_parser/1","doc":"","ref":"Minipeg.Parsers.html#int_parser/1"},{"type":"function","title":"Minipeg.Parsers.keywords_parser/2","doc":"Succeeds if any of the given keywords parse","ref":"Minipeg.Parsers.html#keywords_parser/2"},{"type":"function","title":"Minipeg.Parsers.literal_parser/2","doc":"Parses only an exact occurrance of the `literal` string","ref":"Minipeg.Parsers.html#literal_parser/2"},{"type":"function","title":"Minipeg.Parsers.maybe_escaped_char_parser/4","doc":"Parses any character but delimiter, unless it is escpaed by `escape_char` or \ndoubled in case `allow_doubles` is true.","ref":"Minipeg.Parsers.html#maybe_escaped_char_parser/4"},{"type":"function","title":"Minipeg.Parsers.not_char_parser/2","doc":"Parses any char with the exception of chars in the `forbidden` set","ref":"Minipeg.Parsers.html#not_char_parser/2"},{"type":"function","title":"Minipeg.Parsers.prefixed_parser/3","doc":"parses only if parser parses a string with a prefix that is discarded","ref":"Minipeg.Parsers.html#prefixed_parser/3"},{"type":"function","title":"Minipeg.Parsers.rgx_capture_parser/3","doc":"","ref":"Minipeg.Parsers.html#rgx_capture_parser/3"},{"type":"function","title":"Minipeg.Parsers.rgx_match_parser/3","doc":"","ref":"Minipeg.Parsers.html#rgx_match_parser/3"},{"type":"function","title":"Minipeg.Parsers.rgx_parser/3","doc":"","ref":"Minipeg.Parsers.html#rgx_parser/3"},{"type":"function","title":"Minipeg.Parsers.string_parser/4","doc":"A _classic_ string parser which parses input like\n\n - `\"\"`\n - `'\"a\\\\'b\"c'`\n - `\"ab\"\"c\"`\n\n but not\n\n - `'ab`\n - `\"abc'`\n - `\"ad\"e` (e not parsed)","ref":"Minipeg.Parsers.html#string_parser/4"},{"type":"function","title":"Minipeg.Parsers.success_parser/2","doc":"This parser always succeeds.\n**N.B.** It does not advance the input","ref":"Minipeg.Parsers.html#success_parser/2"},{"type":"function","title":"Minipeg.Parsers.unsigned_int_parser/1","doc":"","ref":"Minipeg.Parsers.html#unsigned_int_parser/1"},{"type":"function","title":"Minipeg.Parsers.upto_parser/3","doc":"parses a string up to the first char in `charset` fails iff less then `min_count` chars are parsed.\nIf a character from `charset` is encountered it is removed from the input stream, but is not returned in the ast.","ref":"Minipeg.Parsers.html#upto_parser/3"},{"type":"function","title":"Minipeg.Parsers.ws_parser/3","doc":"Parses a sequence of at least `min_count` whitespaces.\n`min_count` defaults to 0","ref":"Minipeg.Parsers.html#ws_parser/3"},{"type":"type","title":"Minipeg.Parsers.ast_list_t/0","doc":"","ref":"Minipeg.Parsers.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Parsers.ast_t/0","doc":"","ref":"Minipeg.Parsers.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Parsers.binaries/0","doc":"","ref":"Minipeg.Parsers.html#t:binaries/0"},{"type":"type","title":"Minipeg.Parsers.binary?/0","doc":"","ref":"Minipeg.Parsers.html#t:binary?/0"},{"type":"type","title":"Minipeg.Parsers.char_class_t/0","doc":"","ref":"Minipeg.Parsers.html#t:char_class_t/0"},{"type":"type","title":"Minipeg.Parsers.char_set_t/0","doc":"","ref":"Minipeg.Parsers.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Parsers.either/2","doc":"","ref":"Minipeg.Parsers.html#t:either/2"},{"type":"type","title":"Minipeg.Parsers.input_t/0","doc":"","ref":"Minipeg.Parsers.html#t:input_t/0"},{"type":"type","title":"Minipeg.Parsers.maybe/1","doc":"","ref":"Minipeg.Parsers.html#t:maybe/1"},{"type":"type","title":"Minipeg.Parsers.parser_function_t/0","doc":"","ref":"Minipeg.Parsers.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Parsers.position_t/0","doc":"","ref":"Minipeg.Parsers.html#t:position_t/0"},{"type":"type","title":"Minipeg.Parsers.result_t/0","doc":"","ref":"Minipeg.Parsers.html#t:result_t/0"},{"type":"type","title":"Minipeg.Parsers.satisfier_result_t/0","doc":"","ref":"Minipeg.Parsers.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Parsers.satisfier_t/0","doc":"","ref":"Minipeg.Parsers.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Parsers.str_or_count_t/0","doc":"","ref":"Minipeg.Parsers.html#t:str_or_count_t/0"},{"type":"module","title":"Minipeg.Parsers.LispyParser","doc":"Parses s-expressions (lispy) \nThe syntax is very simple\n\n  s_exp:\n\n    ----> ( `opening_literal`) ---------------------------------------------+-------------> ( `closing_literal` ) ------>\n                                 ^                                          |\n                                 |                                          |\n                                 |                      +---------+         |\n                                 +--- (whitespace) <--- | element | <-------+\n                                                        +---------+ \n\n  element: \n\n      string | integer | name | s_exp\n\n\n`opening_literal` defaults to `(` and closing literal defaults to `)`, of course","ref":"Minipeg.Parsers.LispyParser.html"},{"type":"function","title":"Minipeg.Parsers.LispyParser.element_parser/1","doc":"parses a string, integer, name (atom) or s-exp","ref":"Minipeg.Parsers.LispyParser.html#element_parser/1"},{"type":"function","title":"Minipeg.Parsers.LispyParser.name_parser/1","doc":"Parses a name which is actually any non digit starting printable character sequence","ref":"Minipeg.Parsers.LispyParser.html#name_parser/1"},{"type":"function","title":"Minipeg.Parsers.LispyParser.s_exp_parser/3","doc":"Parses an s-expression according to the schema above","ref":"Minipeg.Parsers.LispyParser.html#s_exp_parser/3"},{"type":"type","title":"Minipeg.Parsers.LispyParser.ast_list_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.ast_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.binaries/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:binaries/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.binary?/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:binary?/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.char_set_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.either/2","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:either/2"},{"type":"type","title":"Minipeg.Parsers.LispyParser.input_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:input_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.maybe/1","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:maybe/1"},{"type":"type","title":"Minipeg.Parsers.LispyParser.parser_function_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.position_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:position_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.result_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:result_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.satisfier_result_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.satisfier_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Parsers.LispyParser.str_or_count_t/0","doc":"","ref":"Minipeg.Parsers.LispyParser.html#t:str_or_count_t/0"},{"type":"module","title":"Minipeg.Success","doc":"A success result","ref":"Minipeg.Success.html"},{"type":"function","title":"Minipeg.Success.succeed/4","doc":"","ref":"Minipeg.Success.html#succeed/4"},{"type":"type","title":"Minipeg.Success.ast_list_t/0","doc":"","ref":"Minipeg.Success.html#t:ast_list_t/0"},{"type":"type","title":"Minipeg.Success.ast_t/0","doc":"","ref":"Minipeg.Success.html#t:ast_t/0"},{"type":"type","title":"Minipeg.Success.binaries/0","doc":"","ref":"Minipeg.Success.html#t:binaries/0"},{"type":"type","title":"Minipeg.Success.binary?/0","doc":"","ref":"Minipeg.Success.html#t:binary?/0"},{"type":"type","title":"Minipeg.Success.char_set_t/0","doc":"","ref":"Minipeg.Success.html#t:char_set_t/0"},{"type":"type","title":"Minipeg.Success.either/2","doc":"","ref":"Minipeg.Success.html#t:either/2"},{"type":"type","title":"Minipeg.Success.input_t/0","doc":"","ref":"Minipeg.Success.html#t:input_t/0"},{"type":"type","title":"Minipeg.Success.maybe/1","doc":"","ref":"Minipeg.Success.html#t:maybe/1"},{"type":"type","title":"Minipeg.Success.parser_function_t/0","doc":"","ref":"Minipeg.Success.html#t:parser_function_t/0"},{"type":"type","title":"Minipeg.Success.position_t/0","doc":"","ref":"Minipeg.Success.html#t:position_t/0"},{"type":"type","title":"Minipeg.Success.result_t/0","doc":"","ref":"Minipeg.Success.html#t:result_t/0"},{"type":"type","title":"Minipeg.Success.satisfier_result_t/0","doc":"","ref":"Minipeg.Success.html#t:satisfier_result_t/0"},{"type":"type","title":"Minipeg.Success.satisfier_t/0","doc":"","ref":"Minipeg.Success.html#t:satisfier_t/0"},{"type":"type","title":"Minipeg.Success.str_or_count_t/0","doc":"","ref":"Minipeg.Success.html#t:str_or_count_t/0"},{"type":"type","title":"Minipeg.Success.t/0","doc":"","ref":"Minipeg.Success.html#t:t/0"}],"content_type":"text/markdown"}